@@ -1,8 +1,8 @@
-#!/usr/local/bin/perl -w
+#!/usr/local/bin/perl
 
 #---------------------------------------------------------
 #
-# $Id: test.pl,v 1.3 1997/10/05 18:27:49 mergl Exp $
+# $Id: test.pl,v 1.4 1998/02/01 10:00:54 mergl Exp $
 #
 #---------------------------------------------------------
 
@@ -10,6 +10,7 @@ use DBI;
 
 $dbmain = 'template1';
 $dbname = 'pgperltest';
+$dbhost = 'localhost';
 $dbuser = '';
 $dbpass = '';
 
@@ -17,11 +18,11 @@ $cwd = `pwd`;
 chop $cwd;
 $lobject = $cwd . '/README';
 
-my $dbh = DBI->connect("dbi:Pg:$dbmain", $dbuser, $dbpass);
+my $dbh = DBI->connect("dbi:Pg:dbname=$dbmain;host=$dbhost", $dbuser, $dbpass);
 $dbh->do( "CREATE DATABASE $dbname" );
 $dbh->disconnect;
 
-$dbh = DBI->connect("dbi:Pg:$dbname", $dbuser, $dbpass);
+$dbh = DBI->connect("dbi:Pg:dbname=$dbname;host=$dbhost", $dbuser, $dbpass);
 
 $dbh->do("CREATE TABLE lobject ( id int4, loid oid )");
 
@@ -41,7 +42,7 @@ $sth->finish;
 
 $dbh->disconnect;
 
-$dbh = DBI->connect("dbi:Pg:$dbmain", $dbuser, $dbpass);
+$dbh = DBI->connect("dbi:Pg:dbname=$dbmain;host=$dbhost", $dbuser, $dbpass);
 $dbh->do( "DROP DATABASE $dbname" );
 $dbh->disconnect;
 
